diff --git a/wp-admin/user-edit.php b/wp-admin/user-edit.php
index 9e6ae4c278..45fe5ecea3 100644
--- a/wp-admin/user-edit.php
+++ b/wp-admin/user-edit.php
@@ -185,19 +185,19 @@ switch ( $action ) {
// Intentional fall-through to display $errors.
default:
- $profileuser = get_user_to_edit( $user_id );
+ $profile_user = get_user_to_edit( $user_id );
if ( ! current_user_can( 'edit_user', $user_id ) ) {
wp_die( __( 'Sorry, you are not allowed to edit this user.' ) );
}
- $title = sprintf( $title, $profileuser->display_name );
- $sessions = WP_Session_Tokens::get_instance( $profileuser->ID );
+ $title = sprintf( $title, $profile_user->display_name );
+ $sessions = WP_Session_Tokens::get_instance( $profile_user->ID );
require_once ABSPATH . 'wp-admin/admin-header.php';
?>
- ID ) && current_user_can( 'manage_network_options' ) ) { ?>
+ ID ) && current_user_can( 'manage_network_options' ) ) { ?>
|
- |
@@ -327,7 +327,7 @@ switch ( $action ) {
|
- comment_shortcuts ); ?> />
+ comment_shortcuts ); ?> />
More information' ); ?>
@@ -339,7 +339,7 @@ switch ( $action ) {
| |
- ID ) ); ?> />
+ ID ) ); ?> />
|
@@ -356,7 +356,7 @@ switch ( $action ) {
locale;
+ $user_locale = $profile_user->locale;
if ( 'en_US' === $user_locale ) {
$user_locale = '';
@@ -387,9 +387,9 @@ endif;
*
* @since 2.7.0
*
* @param WP_User $profileuser The current WP_User object.
*/
- do_action( 'personal_options', $profileuser );
+ do_action( 'personal_options', $profile_user );
?>
@@ -402,9 +402,9 @@ endif;
*
* @since 2.0.0
*
* @param WP_User $profileuser The current WP_User object.
*/
- do_action( 'profile_personal_options', $profileuser );
+ do_action( 'profile_personal_options', $profile_user );
}
?>
@@ -413,15 +413,15 @@ endif;
|
@@ -387,9 +387,9 @@ endif;
* @since 2.7.0
*
- * @param WP_User $profileuser The current WP_User object.
+ * @param WP_User $profile_user The current WP_User object.
*/
@@ -402,9 +402,9 @@ endif;
* @since 2.0.0
*
- * @param WP_User $profileuser The current WP_User object.
+ * @param WP_User $profile_user The current WP_User object.
*/